@@ -2,7 +2,6 @@
 Custom lint tests.
 """
 
-import subprocess
 from pathlib import Path
 
 import pytest
@@ -23,14 +22,21 @@ def _ci_patterns() -> set[str]:
     return ci_patterns
 
 
-def _tests_from_pattern(ci_pattern: str) -> set[str]:
+def _tests_from_pattern(
+    ci_pattern: str,
+    capsys: pytest.CaptureFixture[str],
+) -> set[str]:
     """
     From a CI pattern, get all tests ``pytest`` would collect.
     """
+    # Clear the captured output.
+    capsys.readouterr()
     tests: set[str] = set()
-    args = ["pytest", "-q", "--collect-only", ci_pattern]
-    result = subprocess.run(args=args, stdout=subprocess.PIPE, check=True)
-    for line in result.stdout.decode().splitlines():
+    pytest.main(args=["-q", "--collect-only", ci_pattern])
+    data = capsys.readouterr().out
+    for line in data.splitlines():
+        # We filter empty lines and lines which look like
+        # "9 tests collected in 0.01s".
         if line and "collected in" not in line:
             tests.add(line)
     return tests
@@ -50,7 +56,9 @@ def test_ci_patterns_valid() -> None:
         assert collect_only_result == 0, message
 
 
-def test_tests_collected_once() -> None:
+def test_tests_collected_once(
+    capsys: pytest.CaptureFixture[str],
+) -> None:
     """
     Each test in the test suite is collected exactly once.
 
@@ -58,8 +66,9 @@ def test_tests_collected_once() -> None:
     """
     ci_patterns = _ci_patterns()
     tests_to_patterns: dict[str, set[str]] = {}
+
     for pattern in ci_patterns:
-        tests = _tests_from_pattern(ci_pattern=pattern)
+        tests = _tests_from_pattern(ci_pattern=pattern, capsys=capsys)
         for test in tests:
             if test in tests_to_patterns:
                 tests_to_patterns[test].add(pattern)
@@ -74,6 +83,6 @@ def test_tests_collected_once() -> None:
         )
         assert len(patterns) == 1, message
 
-    all_tests = _tests_from_pattern(ci_pattern=".")
+    all_tests = _tests_from_pattern(ci_pattern=".", capsys=capsys)
     assert tests_to_patterns.keys() - all_tests == set()
     assert all_tests - tests_to_patterns.keys() == set()
