@@ -12,6 +12,7 @@ from http import HTTPStatus
 import requests
 from flask import Flask, Response, request
 from pydantic import BaseSettings
+from werkzeug.datastructures import Headers
 
 from mock_vws._query_tools import (
     ActiveMatchingTargetsDeleteProcessing,
@@ -23,22 +24,30 @@ from mock_vws._query_validators.exceptions import (
     ValidatorException,
 )
 from mock_vws.database import VuforiaDatabase
-from mock_vws.query_matchers import ExactMatcher
+from mock_vws.image_matchers import (
+    AverageHashMatcher,
+    ExactMatcher,
+    ImageMatcher,
+)
 
 CLOUDRECO_FLASK_APP = Flask(import_name=__name__)
 CLOUDRECO_FLASK_APP.config["PROPAGATE_EXCEPTIONS"] = True
 
 
-class _QueryMatcherChoice(StrEnum):
-    """Query matcher choices."""
+class _ImageMatcherChoice(StrEnum):
+    """Image matcher choices."""
 
     EXACT = auto()
+    AVERAGE_HASH = auto()
 
-    def to_query_matcher(self) -> ExactMatcher:
-        """Get the query matcher."""
-        return {
-            _QueryMatcherChoice.EXACT: ExactMatcher(),
+    def to_image_matcher(self) -> ImageMatcher:
+        """Get the image matcher."""
+        matcher = {
+            _ImageMatcherChoice.EXACT: ExactMatcher(),
+            _ImageMatcherChoice.AVERAGE_HASH: AverageHashMatcher(threshold=10),
         }[self]
+        assert isinstance(matcher, ImageMatcher)
+        return matcher
 
 
 class VWQSettings(BaseSettings):
@@ -47,8 +56,8 @@ class VWQSettings(BaseSettings):
     vwq_host: str = ""
     target_manager_base_url: str
     deletion_processing_seconds: float = 3.0
-    deletion_recognition_seconds: float = 0.2
-    query_matcher: _QueryMatcherChoice = _QueryMatcherChoice.EXACT
+    deletion_recognition_seconds: float = 2.0
+    query_image_matcher: _ImageMatcherChoice = _ImageMatcherChoice.AVERAGE_HASH
 
 
 def get_all_databases() -> set[VuforiaDatabase]:
@@ -88,33 +97,20 @@ def set_terminate_wsgi_input() -> None:
     request.environ["wsgi.input_terminated"] = terminate_wsgi_input
 
 
-class ResponseNoContentTypeAdded(Response):
-    """
-    A custom response type.
-
-    Without this, a content type is added to all responses.
-    Some of our responses need to not have a "Content-Type" header.
-    """
-
-    # The type in Flask is incorrect.
-    # See https://github.com/pallets/flask/pull/5034.
-    default_mimetype = None  # type: ignore[assignment]
-
-
-CLOUDRECO_FLASK_APP.response_class = ResponseNoContentTypeAdded
-
-
 @CLOUDRECO_FLASK_APP.errorhandler(ValidatorException)
 def handle_exceptions(exc: ValidatorException) -> Response:
     """
     Return the error response associated with the given exception.
     """
-    return ResponseNoContentTypeAdded(
+    response = Response(
         status=exc.status_code.value,
         response=exc.response_text,
         headers=exc.headers,
     )
 
+    response.headers = Headers(exc.headers)
+    return response
+
 
 @CLOUDRECO_FLASK_APP.route("/v1/query", methods=["POST"])
 def query() -> Response:
@@ -122,7 +118,7 @@ def query() -> Response:
     Perform an image recognition query.
     """
     settings = VWQSettings.parse_obj(obj={})
-    match_checker = settings.query_matcher.to_query_matcher()
+    query_match_checker = settings.query_image_matcher.to_image_matcher()
 
     databases = get_all_databases()
     request_body = request.stream.read()
@@ -146,7 +142,7 @@ def query() -> Response:
             query_recognizes_deletion_seconds=(
                 settings.deletion_recognition_seconds
             ),
-            match_checker=match_checker,
+            query_match_checker=query_match_checker,
         )
     except ActiveMatchingTargetsDeleteProcessing as exc:
         raise DeletedTargetMatched from exc
@@ -166,4 +162,4 @@ def query() -> Response:
 
 if __name__ == "__main__":  # pragma: no cover
     SETTINGS = VWQSettings.parse_obj(obj={})
-    CLOUDRECO_FLASK_APP.run(debug=True, host=SETTINGS.vwq_host)
+    CLOUDRECO_FLASK_APP.run(host=SETTINGS.vwq_host)
