@@ -10,11 +10,13 @@ import email.utils
 import json
 import logging
 import uuid
+from enum import StrEnum, auto
 from http import HTTPStatus
 
 import requests
 from flask import Flask, Response, request
 from pydantic import BaseSettings
+from werkzeug.datastructures import Headers
 
 from mock_vws._constants import ResultCodes, TargetStatuses
 from mock_vws._database_matchers import get_database_matching_server_keys
@@ -27,7 +29,15 @@ from mock_vws._services_validators.exceptions import (
     ValidatorException,
 )
 from mock_vws.database import VuforiaDatabase
+from mock_vws.image_matchers import (
+    AverageHashMatcher,
+    ExactMatcher,
+    ImageMatcher,
+)
 from mock_vws.target import Target
+from mock_vws.target_raters import (
+    HardcodedTargetTrackingRater,
+)
 
 VWS_FLASK_APP = Flask(import_name=__name__)
 VWS_FLASK_APP.config["PROPAGATE_EXCEPTIONS"] = True
@@ -36,12 +46,31 @@ VWS_FLASK_APP.config["PROPAGATE_EXCEPTIONS"] = True
 _LOGGER = logging.getLogger(__name__)
 
 
+class _ImageMatcherChoice(StrEnum):
+    """Image matcher choices."""
+
+    EXACT = auto()
+    AVERAGE_HASH = auto()
+
+    def to_image_matcher(self) -> ImageMatcher:
+        """Get the image matcher."""
+        matcher = {
+            _ImageMatcherChoice.EXACT: ExactMatcher(),
+            _ImageMatcherChoice.AVERAGE_HASH: AverageHashMatcher(threshold=10),
+        }[self]
+        assert isinstance(matcher, ImageMatcher)
+        return matcher
+
+
 class VWSSettings(BaseSettings):
     """Settings for the VWS Flask app."""
 
     target_manager_base_url: str
-    processing_time_seconds: float = 0.5
+    processing_time_seconds: float = 2
     vws_host: str = ""
+    duplicates_image_matcher: _ImageMatcherChoice = (
+        _ImageMatcherChoice.AVERAGE_HASH
+    )
 
 
 def get_all_databases() -> set[VuforiaDatabase]:
@@ -49,9 +78,10 @@ def get_all_databases() -> set[VuforiaDatabase]:
     Get all database objects from the task manager back-end.
     """
     settings = VWSSettings.parse_obj(obj={})
+    timeout_seconds = 30
     response = requests.get(
         url=f"{settings.target_manager_base_url}/databases",
-        timeout=30,
+        timeout=timeout_seconds,
     )
     return {
         VuforiaDatabase.from_dict(database_dict=database_dict)
@@ -59,22 +89,6 @@ def get_all_databases() -> set[VuforiaDatabase]:
     }
 
 
-class ResponseNoContentTypeAdded(Response):
-    """
-    A custom response type.
-
-    Without this, a content type is added to all responses.
-    Some of our responses need to not have a "Content-Type" header.
-    """
-
-    # The type in Flask is incorrect.
-    # See https://github.com/pallets/flask/pull/5034.
-    default_mimetype = None  # type: ignore[assignment]
-
-
-VWS_FLASK_APP.response_class = ResponseNoContentTypeAdded
-
-
 @VWS_FLASK_APP.before_request
 def set_terminate_wsgi_input() -> None:
     """
@@ -117,12 +131,15 @@ def handle_exceptions(exc: ValidatorException) -> Response:
     """
     Return the error response associated with the given exception.
     """
-    return ResponseNoContentTypeAdded(
+    response = Response(
         status=exc.status_code.value,
         response=exc.response_text,
         headers=exc.headers,
     )
 
+    response.headers = Headers(exc.headers)
+    return response
+
 
 @VWS_FLASK_APP.route("/targets", methods=["POST"])
 def add_target() -> Response:
@@ -152,6 +169,9 @@ def add_target() -> Response:
     if active_flag is None:
         active_flag = True
 
+    # This rater is not used.
+    target_tracking_rater = HardcodedTargetTrackingRater(rating=1)
+
     new_target = Target(
         name=name,
         width=request_json["width"],
@@ -159,13 +179,15 @@ def add_target() -> Response:
         active_flag=active_flag,
         processing_time_seconds=settings.processing_time_seconds,
         application_metadata=request_json.get("application_metadata"),
+        target_tracking_rater=target_tracking_rater,
     )
 
     databases_url = f"{settings.target_manager_base_url}/databases"
+    timeout_seconds = 30
     requests.post(
         url=f"{databases_url}/{database.database_name}/targets",
         json=new_target.to_dict(),
-        timeout=30,
+        timeout=timeout_seconds,
     )
 
     date = email.utils.formatdate(None, localtime=False, usegmt=True)
@@ -210,9 +232,9 @@ def get_target(target_id: str) -> Response:
     )
 
     assert isinstance(database, VuforiaDatabase)
-    [target] = [
+    (target,) = (
         target for target in database.targets if target.target_id == target_id
-    ]
+    )
 
     target_record = {
         "target_id": target.target_id,
@@ -265,9 +287,9 @@ def delete_target(target_id: str) -> Response:
     )
 
     assert isinstance(database, VuforiaDatabase)
-    [target] = [
+    (target,) = (
         target for target in database.targets if target.target_id == target_id
-    ]
+    )
 
     if target.status == TargetStatuses.PROCESSING.value:
         raise TargetStatusProcessing
@@ -370,9 +392,9 @@ def target_summary(target_id: str) -> Response:
     )
 
     assert isinstance(database, VuforiaDatabase)
-    [target] = [
+    (target,) = (
         target for target in database.targets if target.target_id == target_id
-    ]
+    )
     body = {
         "status": target.status,
         "transaction_id": uuid.uuid4().hex,
@@ -412,6 +434,7 @@ def get_duplicates(target_id: str) -> Response:
     https://library.vuforia.com/articles/Solution/How-To-Use-the-Vuforia-Web-Services-API.html#How-To-Check-for-Duplicate-Targets
     """
     databases = get_all_databases()
+    settings = VWSSettings.parse_obj(obj={})
     database = get_database_matching_server_keys(
         request_headers=dict(request.headers),
         request_body=request.data,
@@ -419,18 +442,22 @@ def get_duplicates(target_id: str) -> Response:
         request_path=request.path,
         databases=databases,
     )
+    image_match_checker = settings.duplicates_image_matcher.to_image_matcher()
 
     assert isinstance(database, VuforiaDatabase)
-    [target] = [
+    (target,) = (
         target for target in database.targets if target.target_id == target_id
-    ]
-    other_targets = set(database.targets) - {target}
+    )
+    other_targets = database.targets - {target}
 
     similar_targets: list[str] = [
         other.target_id
         for other in other_targets
-        if other.image_value == target.image_value
-        and TargetStatuses.FAILED.value not in (target.status, other.status)
+        if image_match_checker(
+            first_image_content=target.image_value,
+            second_image_content=other.image_value,
+        )
+        and TargetStatuses.FAILED.value not in {target.status, other.status}
         and TargetStatuses.PROCESSING.value != other.status
         and other.active_flag
     ]
@@ -521,9 +548,9 @@ def update_target(target_id: str) -> Response:
     )
 
     assert isinstance(database, VuforiaDatabase)
-    [target] = [
+    (target,) = (
         target for target in database.targets if target.target_id == target_id
-    ]
+    )
 
     if target.status != TargetStatuses.SUCCESS.value:
         raise TargetStatusNotSuccess
@@ -565,8 +592,8 @@ def update_target(target_id: str) -> Response:
         update_values["image"] = image
 
     put_url = (
-        f"{settings.target_manager_base_url}/databases/{database.database_name}/"
-        f"targets/{target_id}"
+        f"{settings.target_manager_base_url}/databases/"
+        f"{database.database_name}/targets/{target_id}"
     )
     requests.put(url=put_url, json=update_values, timeout=30)
 
@@ -593,4 +620,4 @@ def update_target(target_id: str) -> Response:
 
 if __name__ == "__main__":  # pragma: no cover
     SETTINGS = VWSSettings.parse_obj(obj={})
-    VWS_FLASK_APP.run(debug=True, host=SETTINGS.vws_host)
+    VWS_FLASK_APP.run(host=SETTINGS.vws_host)
