@@ -21,7 +21,7 @@ from mock_vws._mock_common import json_dump
 from mock_vws.database import VuforiaDatabase
 
 if TYPE_CHECKING:
-    from mock_vws.query_matchers import QueryMatcher
+    from mock_vws.image_matchers import ImageMatcher
 
 
 class ActiveMatchingTargetsDeleteProcessing(Exception):
@@ -38,7 +38,7 @@ def get_query_match_response_text(
     databases: set[VuforiaDatabase],
     query_processes_deletion_seconds: int | float,
     query_recognizes_deletion_seconds: int | float,
-    match_checker: QueryMatcher,
+    query_match_checker: ImageMatcher,
 ) -> str:
     """
     Args:
@@ -53,8 +53,8 @@ def get_query_match_response_text(
         query_processes_deletion_seconds: The number of seconds after a target
             deletion is recognized that the query endpoint will return a 500
             response on a match.
-        match_checker: A callable which takes two image values and returns
-            whether they match.
+        query_match_checker: A callable which takes two image values and
+            returns whether they match.
 
     Returns:
         The response text for a query endpoint request.
@@ -109,9 +109,9 @@ def get_query_match_response_text(
     matching_targets = [
         target
         for target in database.targets
-        if match_checker(
-            database_image_content=target.image_value,
-            query_image_content=image_value,
+        if query_match_checker(
+            first_image_content=target.image_value,
+            second_image_content=image_value,
         )
     ]
 
@@ -144,7 +144,13 @@ def get_query_match_response_text(
     if active_matching_targets_delete_processing:
         raise ActiveMatchingTargetsDeleteProcessing
 
-    matches = not_deleted_matches + deletion_not_recognized_matches
+    all_quality_matches = not_deleted_matches + deletion_not_recognized_matches
+    minimum_rating = 0
+    matches = [
+        match
+        for match in all_quality_matches
+        if match.tracking_rating > minimum_rating
+    ]
 
     results: list[dict[str, Any]] = []
     for target in matches:
