@@ -12,17 +12,23 @@ from urllib.parse import urljoin, urlparse
 import requests
 from requests_mock.mocker import Mocker
 
-from mock_vws.query_matchers import ExactMatcher, QueryMatcher
+from mock_vws.image_matchers import (
+    AverageHashMatcher,
+    ImageMatcher,
+)
 from mock_vws.target_manager import TargetManager
+from mock_vws.target_raters import BrisqueTargetTrackingRater
 
 from .mock_web_query_api import MockVuforiaWebQueryAPI
 from .mock_web_services_api import MockVuforiaWebServicesAPI
 
 if TYPE_CHECKING:
     from mock_vws.database import VuforiaDatabase
+    from mock_vws.target_raters import TargetTrackingRater
 
 
-_EXACT_MATCHER = ExactMatcher()
+_AVERAGE_HASH_MATCHER = AverageHashMatcher(threshold=10)
+_BRISQUE_TRACKING_RATER = BrisqueTargetTrackingRater()
 
 
 class MockVWS(ContextDecorator):
@@ -34,10 +40,12 @@ class MockVWS(ContextDecorator):
         self,
         base_vws_url: str = "https://vws.vuforia.com",
         base_vwq_url: str = "https://cloudreco.vuforia.com",
-        match_checker: QueryMatcher = _EXACT_MATCHER,
-        processing_time_seconds: int | float = 0.5,
-        query_recognizes_deletion_seconds: int | float = 0.2,
+        duplicate_match_checker: ImageMatcher = _AVERAGE_HASH_MATCHER,
+        query_match_checker: ImageMatcher = _AVERAGE_HASH_MATCHER,
+        processing_time_seconds: int | float = 2,
+        query_recognizes_deletion_seconds: int | float = 2,
         query_processes_deletion_seconds: int | float = 3,
+        target_tracking_rater: TargetTrackingRater = _BRISQUE_TRACKING_RATER,
         *,
         real_http: bool = False,
     ) -> None:
@@ -49,8 +57,8 @@ class MockVWS(ContextDecorator):
                 server if they are not handled by the mock.
                 See
                 https://requests-mock.readthedocs.io/en/latest/mocker.html#real-http-requests.
-            processing_time_seconds: The number of seconds
-                to process each image for.
+            processing_time_seconds: The number of seconds to process each
+                image for.
                 In the real Vuforia Web Services, this is not deterministic.
             base_vwq_url: The base URL for the VWQ API.
             base_vws_url: The base URL for the VWS API.
@@ -60,8 +68,11 @@ class MockVWS(ContextDecorator):
             query_processes_deletion_seconds: The number of
                 seconds after a target deletion is recognized that the query
                 endpoint will return a 500 response on a match.
-            match_checker: A callable which takes two image values and returns
-                whether they will match in a query request.
+            query_match_checker: A callable which takes two image values and
+                returns whether they will match in a query request.
+            duplicate_match_checker: A callable which takes two image values
+                and returns whether they are duplicates.
+            target_tracking_rater: A callable for rating targets for tracking.
 
         Raises:
             requests.exceptions.MissingSchema: There is no schema in a given
@@ -79,14 +90,16 @@ class MockVWS(ContextDecorator):
             'Perhaps you meant "https://{url}".'
         )
         for url in (base_vwq_url, base_vws_url):
-            result = urlparse(url)
-            if not result.scheme:
+            parse_result = urlparse(url=url)
+            if not parse_result.scheme:
                 error = missing_scheme_error.format(url=url)
                 raise requests.exceptions.MissingSchema(error)
 
         self._mock_vws_api = MockVuforiaWebServicesAPI(
             target_manager=self._target_manager,
             processing_time_seconds=processing_time_seconds,
+            duplicate_match_checker=duplicate_match_checker,
+            target_tracking_rater=target_tracking_rater,
         )
 
         self._mock_vwq_api = MockVuforiaWebQueryAPI(
@@ -97,7 +110,7 @@ class MockVWS(ContextDecorator):
             query_recognizes_deletion_seconds=(
                 query_recognizes_deletion_seconds
             ),
-            match_checker=match_checker,
+            query_match_checker=query_match_checker,
         )
 
     def add_database(self, database: VuforiaDatabase) -> None:
@@ -121,30 +134,30 @@ class MockVWS(ContextDecorator):
             ``self``.
         """
         with Mocker(real_http=self._real_http) as mock:
-            for route in self._mock_vws_api.routes:
+            for vws_route in self._mock_vws_api.routes:
                 url_pattern = urljoin(
                     base=self._base_vws_url,
-                    url=route.path_pattern + "$",
+                    url=f"{vws_route.path_pattern}$",
                 )
 
-                for http_method in route.http_methods:
+                for vws_http_method in vws_route.http_methods:
                     mock.register_uri(
-                        method=http_method,
+                        method=vws_http_method,
                         url=re.compile(url_pattern),
-                        text=getattr(self._mock_vws_api, route.route_name),
+                        text=getattr(self._mock_vws_api, vws_route.route_name),
                     )
 
-            for route in self._mock_vwq_api.routes:
+            for vwq_route in self._mock_vwq_api.routes:
                 url_pattern = urljoin(
                     base=self._base_vwq_url,
-                    url=route.path_pattern + "$",
+                    url=f"{vwq_route.path_pattern}$",
                 )
 
-                for http_method in route.http_methods:
+                for vwq_http_method in vwq_route.http_methods:
                     mock.register_uri(
-                        method=http_method,
+                        method=vwq_http_method,
                         url=re.compile(url_pattern),
-                        text=getattr(self._mock_vwq_api, route.route_name),
+                        text=getattr(self._mock_vwq_api, vwq_route.route_name),
                     )
 
         self._mock = mock
@@ -161,8 +174,7 @@ class MockVWS(ContextDecorator):
         """
         # __exit__ needs this to be passed in but vulture thinks that it is
         # unused, so we "use" it here.
-        for _ in (exc,):
-            pass
+        assert isinstance(exc, tuple)
 
         self._mock.stop()
         return False
