@@ -37,7 +37,9 @@ if TYPE_CHECKING:
     from requests_mock.request import _RequestObjectProxy
     from requests_mock.response import _Context
 
+    from mock_vws.image_matchers import ImageMatcher
     from mock_vws.target_manager import TargetManager
+    from mock_vws.target_raters import TargetTrackingRater
 
 _TARGET_ID_PATTERN = "[A-Za-z0-9]+"
 
@@ -54,7 +56,7 @@ def route(
 
     Args:
         path_pattern: The end part of a URL pattern. E.g. `/targets` or
-            `/targets/.+`.
+          `/targets/.+`.
         http_methods: HTTP methods that map to the route function.
 
     Returns:
@@ -93,13 +95,18 @@ class MockVuforiaWebServicesAPI:
         self,
         target_manager: TargetManager,
         processing_time_seconds: int | float,
+        duplicate_match_checker: ImageMatcher,
+        target_tracking_rater: TargetTrackingRater,
     ) -> None:
         """
         Args:
             target_manager: Target Manager which stores databases.
             processing_time_seconds: The number of seconds to process each
-                image for. In the real Vuforia Web Services, this is not
-                deterministic.
+              image for. In the real Vuforia Web Services, this is not
+              deterministic.
+            duplicate_match_checker: A callable which takes two image values
+              and returns whether they are duplicates.
+            target_tracking_rater: A callable for rating targets for tracking.
 
         Attributes:
             routes: The `Route`s to be used in the mock.
@@ -107,6 +114,8 @@ class MockVuforiaWebServicesAPI:
         self._target_manager = target_manager
         self.routes: set[Route] = _ROUTES
         self._processing_time_seconds = processing_time_seconds
+        self._duplicate_match_checker = duplicate_match_checker
+        self._target_tracking_rater = target_tracking_rater
 
     @route(
         path_pattern="/targets",
@@ -162,6 +171,7 @@ class MockVuforiaWebServicesAPI:
             active_flag=active_flag,
             processing_time_seconds=self._processing_time_seconds,
             application_metadata=application_metadata,
+            target_tracking_rater=self._target_tracking_rater,
         )
         database.targets.add(new_target)
 
@@ -357,11 +367,13 @@ class MockVuforiaWebServicesAPI:
         assert isinstance(database, VuforiaDatabase)
         date = email.utils.formatdate(None, localtime=False, usegmt=True)
 
-        results = [target.target_id for target in database.not_deleted_targets]
+        response_results = [
+            target.target_id for target in database.not_deleted_targets
+        ]
         body: dict[str, str | list[str]] = {
             "transaction_id": uuid.uuid4().hex,
             "result_code": ResultCodes.SUCCESS.value,
-            "results": results,
+            "results": response_results,
         }
         body_json = json_dump(body)
         context.headers = {
@@ -480,14 +492,17 @@ class MockVuforiaWebServicesAPI:
         target_id = request.path.split("/")[-1]
         target = database.get_target(target_id=target_id)
 
-        other_targets = set(database.targets) - {target}
+        other_targets = database.targets - {target}
 
         similar_targets: list[str] = [
             other.target_id
             for other in other_targets
-            if other.image_value == target.image_value
+            if self._duplicate_match_checker(
+                first_image_content=target.image_value,
+                second_image_content=other.image_value,
+            )
             and TargetStatuses.FAILED.value
-            not in (target.status, other.status)
+            not in {target.status, other.status}
             and TargetStatuses.PROCESSING.value != other.status
             and other.active_flag
         ]
