@@ -27,7 +27,7 @@ def validate_content_type_header_given(
         AuthenticationFailure: No ``Content-Type`` header is given and the
             request requires one.
     """
-    request_needs_content_type = bool(request_method in (POST, PUT))
+    request_needs_content_type = bool(request_method in {POST, PUT})
     if request_headers.get("Content-Type") or not request_needs_content_type:
         return
 
