@@ -3,11 +3,13 @@ Validators for the width field.
 """
 
 import json
-import numbers
+import logging
 from http import HTTPStatus
 
 from mock_vws._services_validators.exceptions import Fail
 
+_LOGGER = logging.getLogger(__name__)
+
 
 def validate_width(request_body: bytes) -> None:
     """
@@ -28,8 +30,9 @@ def validate_width(request_body: bytes) -> None:
 
     width = json.loads(request_text).get("width")
 
-    width_is_number = isinstance(width, numbers.Number)
+    width_is_number = isinstance(width, int | float)
     width_positive = width_is_number and width > 0
 
     if not width_positive:
+        _LOGGER.warning(msg="Width is not a positive number.")
         raise Fail(status_code=HTTPStatus.BAD_REQUEST)
