@@ -449,9 +449,7 @@ def query(
     files = {"image": ("image.jpeg", image_content, "image/jpeg")}
     method = POST
 
-    content, content_type_header = encode_multipart_formdata(
-        fields=files,
-    )  # type: ignore[no-untyped-call]
+    content, content_type_header = encode_multipart_formdata(fields=files)
 
     access_key = vuforia_database.client_access_key
     secret_key = vuforia_database.client_secret_key
