@@ -90,7 +90,7 @@ def _enable_use_mock_vuforia(
         client_secret_key=inactive_database.client_secret_key,
     )
 
-    with MockVWS(processing_time_seconds=0.2) as mock:
+    with MockVWS() as mock:
         mock.add_database(database=working_database)
         mock.add_database(database=inactive_database)
         yield
@@ -230,6 +230,9 @@ def verify_mock_vuforia(
     real Vuforia, and once with each mock.
 
     This is useful for verifying the mocks.
+
+    Yields:
+        ``None``.
     """
     backend = request.param
     should_skip = request.config.getoption(f"--skip-{backend.name.lower()}")
