@@ -69,14 +69,14 @@ class TestProcessingTime:
 
     # There is a race condition in this test type - if tests start to
     # fail, consider increasing the leeway.
-    LEEWAY = 0.1
+    LEEWAY = 0.5
 
     def test_default(
         self,
         image_file_failed_state: io.BytesIO,
     ) -> None:
         """
-        By default, targets in the mock take 0.5 seconds to be processed.
+        By default, targets in the mock takes 2 seconds to be processed.
         """
         database = VuforiaDatabase()
         databases_url = _EXAMPLE_URL_FOR_TARGET_MANAGER + "/databases"
@@ -87,8 +87,8 @@ class TestProcessingTime:
             image=image_file_failed_state,
         )
 
-        expected = 0.5
-        assert abs(expected - time_taken) < self.LEEWAY
+        expected = 2
+        assert expected - self.LEEWAY < time_taken < expected + self.LEEWAY
 
     def test_custom(
         self,
@@ -98,9 +98,10 @@ class TestProcessingTime:
         """
         It is possible to set a custom processing time.
         """
+        seconds = 5
         monkeypatch.setenv(
             name="PROCESSING_TIME_SECONDS",
-            value="0.1",
+            value=str(seconds),
         )
         database = VuforiaDatabase()
         databases_url = _EXAMPLE_URL_FOR_TARGET_MANAGER + "/databases"
@@ -111,8 +112,8 @@ class TestProcessingTime:
             image=image_file_failed_state,
         )
 
-        expected = 0.1
-        assert abs(expected - time_taken) < self.LEEWAY
+        expected = seconds
+        assert expected - self.LEEWAY < time_taken < expected + self.LEEWAY
 
 
 class TestCustomQueryRecognizesDeletionSeconds:
@@ -121,20 +122,25 @@ class TestCustomQueryRecognizesDeletionSeconds:
     until it is not recognized by the query endpoint.
     """
 
-    LEEWAY = 0.15
+    LEEWAY = 0.5
 
     def test_default(
         self,
         high_quality_image: io.BytesIO,
+        monkeypatch: pytest.MonkeyPatch,
     ) -> None:
         """
-        By default it takes zero seconds for the Query API on the mock to
+        By default it takes 2 seconds for the Query API on the mock to
         recognize that a target has been deleted.
 
         The real Query API takes between zero and two seconds.
         See ``test_query`` for more information.
         """
         database = VuforiaDatabase()
+        # Use the "exact" matcher, as it is the fastest.
+        monkeypatch.setenv(name="QUERY_IMAGE_MATCHER", value="exact")
+        # Use the fastest tracking rater.
+        monkeypatch.setenv(name="TARGET_RATER", value="perfect")
         databases_url = _EXAMPLE_URL_FOR_TARGET_MANAGER + "/databases"
         requests.post(url=databases_url, json=database.to_dict(), timeout=30)
         time_taken = recognize_deletion_seconds(
@@ -142,34 +148,40 @@ class TestCustomQueryRecognizesDeletionSeconds:
             vuforia_database=database,
         )
 
-        expected = 0.2
-        assert abs(expected - time_taken) < self.LEEWAY
+        expected = 2
+        assert expected - self.LEEWAY < time_taken < expected + self.LEEWAY
 
+    @pytest.mark.parametrize(
+        argnames=["seconds"],
+        # We include 0 because it exercises some otherwise untouched code.
+        argvalues=[(0,), (5,)],
+    )
     def test_custom(
         self,
         high_quality_image: io.BytesIO,
         monkeypatch: pytest.MonkeyPatch,
+        seconds: int | float,
     ) -> None:
         """
         It is possible to use set a custom amount of time that it takes for the
         Query API on the mock to recognize that a target has been deleted.
         """
-        # We choose a low time for a quick test.
-        query_recognizes_deletion = 0.5
         database = VuforiaDatabase()
         databases_url = _EXAMPLE_URL_FOR_TARGET_MANAGER + "/databases"
         requests.post(url=databases_url, json=database.to_dict(), timeout=30)
         monkeypatch.setenv(
             name="DELETION_RECOGNITION_SECONDS",
-            value=str(query_recognizes_deletion),
+            value=str(seconds),
         )
+        # Use the "exact" matcher, as it is the fastest.
+        monkeypatch.setenv(name="QUERY_IMAGE_MATCHER", value="exact")
         time_taken = recognize_deletion_seconds(
             high_quality_image=high_quality_image,
             vuforia_database=database,
         )
 
-        expected = query_recognizes_deletion
-        assert abs(expected - time_taken) < self.LEEWAY
+        expected = seconds
+        assert expected - self.LEEWAY < time_taken < expected + self.LEEWAY
 
 
 class TestCustomQueryProcessDeletionSeconds:
@@ -180,11 +192,12 @@ class TestCustomQueryProcessDeletionSeconds:
 
     # There is a race condition in this test type - if tests start to
     # fail, consider increasing the leeway.
-    LEEWAY = 0.2
+    LEEWAY = 0.5
 
     def test_default(
         self,
         high_quality_image: io.BytesIO,
+        monkeypatch: pytest.MonkeyPatch,
     ) -> None:
         """
         By default it takes three seconds for the Query API on the mock to
@@ -193,6 +206,10 @@ class TestCustomQueryProcessDeletionSeconds:
         The real Query API takes between seven and thirty seconds.
         See ``test_query`` for more information.
         """
+        # Use the "exact" matcher, as it is the fastest.
+        monkeypatch.setenv(name="QUERY_IMAGE_MATCHER", value="exact")
+        # Use the fastest tracking rater.
+        monkeypatch.setenv(name="TARGET_RATER", value="perfect")
         database = VuforiaDatabase()
         databases_url = _EXAMPLE_URL_FOR_TARGET_MANAGER + "/databases"
         requests.post(url=databases_url, json=database.to_dict(), timeout=30)
@@ -202,7 +219,9 @@ class TestCustomQueryProcessDeletionSeconds:
         )
 
         expected = 3
-        assert abs(expected - time_taken) < self.LEEWAY
+        # We minus the leeway because we might start the timer after the
+        # deletion processing has started.
+        assert expected - self.LEEWAY < time_taken < expected + self.LEEWAY
 
     def test_custom(
         self,
@@ -213,8 +232,12 @@ class TestCustomQueryProcessDeletionSeconds:
         It is possible to use set a custom amount of time that it takes for the
         Query API on the mock to process that a target has been deleted.
         """
+        # Use the "exact" matcher, as it is the fastest.
+        monkeypatch.setenv(name="QUERY_IMAGE_MATCHER", value="exact")
+        # Use the fastest tracking rater.
+        monkeypatch.setenv(name="TARGET_RATER", value="perfect")
         # We choose a low time for a quick test.
-        query_processes_deletion = 0.1
+        query_processes_deletion = 5
         database = VuforiaDatabase()
         databases_url = _EXAMPLE_URL_FOR_TARGET_MANAGER + "/databases"
         requests.post(url=databases_url, json=database.to_dict(), timeout=30)
@@ -228,7 +251,9 @@ class TestCustomQueryProcessDeletionSeconds:
         )
 
         expected = query_processes_deletion
-        assert abs(expected - time_taken) < self.LEEWAY
+        # We minus the leeway because we might start the timer after the
+        # deletion processing has started.
+        assert expected - self.LEEWAY < time_taken < expected + self.LEEWAY
 
 
 class TestAddDatabase:
@@ -358,8 +383,8 @@ class TestDeleteDatabase:
         assert response.status_code == HTTPStatus.NOT_FOUND
 
 
-class TestQueryMatchers:
-    """Tests for query matchers."""
+class TestQueryImageMatchers:
+    """Tests for query image matchers."""
 
     @staticmethod
     def test_exact_match(
@@ -367,10 +392,7 @@ class TestQueryMatchers:
         monkeypatch: pytest.MonkeyPatch,
     ) -> None:
         """The exact matcher matches only exactly the same images."""
-        monkeypatch.setenv(
-            name="QUERY_MATCHER",
-            value="exact",
-        )
+        monkeypatch.setenv(name="QUERY_IMAGE_MATCHER", value="exact")
 
         database = VuforiaDatabase()
 
@@ -405,11 +427,16 @@ class TestQueryMatchers:
         different_image_result = cloud_reco_client.query(
             image=re_exported_image,
         )
-        assert len(different_image_result) == 0
+        assert not different_image_result
 
     @staticmethod
-    def test_default(high_quality_image: io.BytesIO) -> None:
-        """The exact matcher is used by default."""
+    def test_average_hash_matcher(
+        high_quality_image: io.BytesIO,
+        different_high_quality_image: io.BytesIO,
+        monkeypatch: pytest.MonkeyPatch,
+    ) -> None:
+        """The average hash matcher matches similar images."""
+        monkeypatch.setenv(name="QUERY_IMAGE_MATCHER", value="average_hash")
         database = VuforiaDatabase()
         vws_client = VWS(
             server_access_key=database.server_access_key,
@@ -420,6 +447,103 @@ class TestQueryMatchers:
             client_secret_key=database.client_secret_key,
         )
 
+        pil_image = Image.open(fp=high_quality_image)
+        re_exported_image = io.BytesIO()
+        pil_image.save(re_exported_image, format="PNG")
+        databases_url = _EXAMPLE_URL_FOR_TARGET_MANAGER + "/databases"
+        requests.post(url=databases_url, json=database.to_dict(), timeout=30)
+
+        target_id = vws_client.add_target(
+            name="example",
+            width=1,
+            image=high_quality_image,
+            application_metadata=None,
+            active_flag=True,
+        )
+        vws_client.wait_for_target_processed(target_id=target_id)
+        same_image_result = cloud_reco_client.query(
+            image=high_quality_image,
+        )
+        assert len(same_image_result) == 1
+        similar_image_result = cloud_reco_client.query(
+            image=re_exported_image,
+        )
+        assert len(similar_image_result) == 1
+
+        different_image_result = cloud_reco_client.query(
+            image=different_high_quality_image,
+        )
+        assert not different_image_result
+
+
+class TestDuplicatesImageMatchers:
+    """Tests for duplicates image matchers."""
+
+    @staticmethod
+    def test_exact_match(
+        high_quality_image: io.BytesIO,
+        monkeypatch: pytest.MonkeyPatch,
+    ) -> None:
+        """The exact matcher matches only exactly the same images."""
+        monkeypatch.setenv(name="DUPLICATES_IMAGE_MATCHER", value="exact")
+        database = VuforiaDatabase()
+        vws_client = VWS(
+            server_access_key=database.server_access_key,
+            server_secret_key=database.server_secret_key,
+        )
+
+        pil_image = Image.open(fp=high_quality_image)
+        re_exported_image = io.BytesIO()
+        pil_image.save(re_exported_image, format="PNG")
+
+        databases_url = _EXAMPLE_URL_FOR_TARGET_MANAGER + "/databases"
+        requests.post(url=databases_url, json=database.to_dict(), timeout=30)
+
+        target_id = vws_client.add_target(
+            name="example_0",
+            width=1,
+            image=high_quality_image,
+            application_metadata=None,
+            active_flag=True,
+        )
+        duplicate_target_id = vws_client.add_target(
+            name="example_1",
+            width=1,
+            image=high_quality_image,
+            application_metadata=None,
+            active_flag=True,
+        )
+        not_duplicate_target_id = vws_client.add_target(
+            name="example_2",
+            width=1,
+            image=re_exported_image,
+            application_metadata=None,
+            active_flag=True,
+        )
+        vws_client.wait_for_target_processed(target_id=target_id)
+        vws_client.wait_for_target_processed(target_id=duplicate_target_id)
+        vws_client.wait_for_target_processed(
+            target_id=not_duplicate_target_id,
+        )
+        duplicates = vws_client.get_duplicate_targets(target_id=target_id)
+        assert duplicates == [duplicate_target_id]
+
+    @staticmethod
+    def test_average_hash_matcher(
+        high_quality_image: io.BytesIO,
+        monkeypatch: pytest.MonkeyPatch,
+    ) -> None:
+        """The average hash matcher matches similar images."""
+        monkeypatch.setenv(
+            name="DUPLICATES_IMAGE_MATCHER",
+            value="average_hash",
+        )
+        database = VuforiaDatabase()
+        vws_client = VWS(
+            server_access_key=database.server_access_key,
+            server_secret_key=database.server_secret_key,
+        )
+
         pil_image = Image.open(fp=high_quality_image)
         re_exported_image = io.BytesIO()
         pil_image.save(re_exported_image, format="PNG")
@@ -434,12 +558,14 @@ class TestQueryMatchers:
             application_metadata=None,
             active_flag=True,
         )
-        vws_client.wait_for_target_processed(target_id=target_id)
-        same_image_result = cloud_reco_client.query(
-            image=high_quality_image,
-        )
-        assert len(same_image_result) == 1
-        different_image_result = cloud_reco_client.query(
+        duplicate_target_id = vws_client.add_target(
+            name="example_1",
+            width=1,
             image=re_exported_image,
+            application_metadata=None,
+            active_flag=True,
         )
-        assert len(different_image_result) == 0
+        vws_client.wait_for_target_processed(target_id=target_id)
+        vws_client.wait_for_target_processed(target_id=duplicate_target_id)
+        duplicates = vws_client.get_duplicate_targets(target_id=target_id)
+        assert duplicates == [duplicate_target_id]
