@@ -8,6 +8,7 @@ from __future__ import annotations
 
 import base64
 import calendar
+import copy
 import datetime
 import io
 import sys
@@ -24,7 +25,6 @@ import pytest
 import requests
 from mock_vws._constants import ResultCodes
 from PIL import Image
-from requests import Response
 from requests_mock import POST
 from urllib3.filepost import encode_multipart_formdata
 from vws.reports import TargetStatuses
@@ -88,7 +88,7 @@ _JETTY_ERROR_DELETION_NOT_COMPLETE = (
 def query(
     vuforia_database: VuforiaDatabase,
     body: dict[str, Any],
-) -> Response:
+) -> requests.Response:
     """
     Make a request to the endpoint to make an image recognition query.
 
@@ -102,9 +102,7 @@ def query(
     """
     date = rfc_1123_date()
     request_path = "/v1/query"
-    content, content_type_header = encode_multipart_formdata(
-        fields=body,
-    )  # type: ignore[no-untyped-call]
+    content, content_type_header = encode_multipart_formdata(fields=body)
     method = POST
 
     access_key = vuforia_database.client_access_key
@@ -144,14 +142,14 @@ class TestContentType:
 
     @staticmethod
     @pytest.mark.parametrize(
-        (
+        argnames=(
             "content_type",
             "resp_status_code",
             "resp_content_type",
             "resp_cache_control",
             "resp_text",
         ),
-        [
+        argvalues=[
             (
                 "text/html",
                 HTTPStatus.UNSUPPORTED_MEDIA_TYPE,
@@ -208,9 +206,7 @@ class TestContentType:
         date = rfc_1123_date()
         request_path = "/v1/query"
         body = {"image": ("image.jpeg", image_content, "image/jpeg")}
-        content, _ = encode_multipart_formdata(
-            fields=body,
-        )  # type: ignore[no-untyped-call]
+        content, _ = encode_multipart_formdata(fields=body)
         method = POST
 
         access_key = vuforia_database.client_access_key
@@ -263,9 +259,7 @@ class TestContentType:
         date = rfc_1123_date()
         request_path = "/v1/query"
         body = {"image": ("image.jpeg", image_content, "image/jpeg")}
-        content, content_type_header = encode_multipart_formdata(
-            fields=body,
-        )  # type: ignore[no-untyped-call]
+        content, content_type_header = encode_multipart_formdata(fields=body)
         method = POST
 
         content_type = "text/html"
@@ -330,9 +324,7 @@ class TestContentType:
         date = rfc_1123_date()
         request_path = "/v1/query"
         body = {"image": ("image.jpeg", image_content, "image/jpeg")}
-        content, _ = encode_multipart_formdata(
-            fields=body,
-        )  # type: ignore[no-untyped-call]
+        content, _ = encode_multipart_formdata(fields=body)
         method = POST
 
         access_key = vuforia_database.client_access_key
@@ -388,9 +380,7 @@ class TestContentType:
         date = rfc_1123_date()
         request_path = "/v1/query"
         body = {"image": ("image.jpeg", image_content, "image/jpeg")}
-        content, _ = encode_multipart_formdata(
-            fields=body,
-        )  # type: ignore[no-untyped-call]
+        content, _ = encode_multipart_formdata(fields=body)
         method = POST
 
         access_key = vuforia_database.client_access_key
@@ -444,9 +434,7 @@ class TestContentType:
         date = rfc_1123_date()
         request_path = "/v1/query"
         body = {"image": ("image.jpeg", image_content, "image/jpeg")}
-        content, content_type_header = encode_multipart_formdata(
-            fields=body,
-        )  # type: ignore[no-untyped-call]
+        content, content_type_header = encode_multipart_formdata(fields=body)
         method = POST
 
         access_key = vuforia_database.client_access_key
@@ -504,22 +492,24 @@ class TestSuccess:
         assert response.json()["results"] == []
 
     @staticmethod
-    def test_match(
+    def test_match_exact(
         high_quality_image: io.BytesIO,
         vuforia_database: VuforiaDatabase,
         vws_client: VWS,
     ) -> None:
         """
-        If the exact image that was added is queried for, target data is shown.
+        If the exact high quality image that was added is queried for, target
+        data is shown.
         """
-        image_content = high_quality_image.getvalue()
+        image_file = high_quality_image
+        image_content = image_file.getvalue()
         metadata_encoded = base64.b64encode(b"example").decode("ascii")
         name = "example_name"
 
         target_id = vws_client.add_target(
             name=name,
             width=1,
-            image=high_quality_image,
+            image=image_file,
             active_flag=True,
             application_metadata=metadata_encoded,
         )
@@ -533,7 +523,7 @@ class TestSuccess:
         response = query(vuforia_database=vuforia_database, body=body)
 
         assert_query_success(response=response)
-        [result] = response.json()["results"]
+        (result,) = response.json()["results"]
         assert result.keys() == {"target_id", "target_data"}
         assert result["target_id"] == target_id
         target_data = result["target_data"]
@@ -550,6 +540,79 @@ class TestSuccess:
         max_time_difference = 5
         assert time_difference < max_time_difference
 
+    @staticmethod
+    def test_low_quality_image(
+        image_file_success_state_low_rating: io.BytesIO,
+        cloud_reco_client: CloudRecoService,
+        vws_client: VWS,
+    ) -> None:
+        """
+        If the exact low quality image that was added is queried for, no
+        results are returned.
+        """
+        image_file = image_file_success_state_low_rating
+        metadata_encoded = base64.b64encode(b"example").decode("ascii")
+        name = "example_name"
+
+        target_id = vws_client.add_target(
+            name=name,
+            width=1,
+            image=image_file,
+            active_flag=True,
+            application_metadata=metadata_encoded,
+        )
+
+        vws_client.wait_for_target_processed(target_id=target_id)
+        matching_targets = cloud_reco_client.query(image=image_file)
+        assert not matching_targets
+
+    @staticmethod
+    def test_match_similar(
+        high_quality_image: io.BytesIO,
+        different_high_quality_image: io.BytesIO,
+        vws_client: VWS,
+        cloud_reco_client: CloudRecoService,
+    ) -> None:
+        """
+        If a similar image to one that was added is queried for, target data is
+        shown.
+        """
+        metadata_encoded = base64.b64encode(b"example").decode("ascii")
+        name_matching = "example_name_matching"
+        name_not_matching = "example_name_not_matching"
+
+        target_id_matching = vws_client.add_target(
+            name=name_matching,
+            width=1,
+            image=high_quality_image,
+            active_flag=True,
+            application_metadata=metadata_encoded,
+        )
+
+        target_id_not_matching = vws_client.add_target(
+            name=name_not_matching,
+            width=1,
+            image=different_high_quality_image,
+            active_flag=True,
+            application_metadata=metadata_encoded,
+        )
+
+        vws_client.wait_for_target_processed(target_id=target_id_matching)
+        vws_client.wait_for_target_processed(target_id=target_id_not_matching)
+
+        similar_image_buffer = io.BytesIO()
+        similar_image_data = copy.copy(high_quality_image)
+        pil_similar_image = Image.open(similar_image_data)
+        # Re-save means similar but not identical.
+        pil_similar_image.save(similar_image_buffer, format="JPEG")
+
+        (matching_target,) = cloud_reco_client.query(
+            image=similar_image_buffer,
+            max_num_results=5,
+        )
+
+        assert matching_target.target_id == target_id_matching
+
     @staticmethod
     def test_not_base64_encoded_processable(
         high_quality_image: io.BytesIO,
@@ -587,7 +650,7 @@ class TestSuccess:
         response = query(vuforia_database=vuforia_database, body=body)
 
         assert_query_success(response=response)
-        [result] = response.json()["results"]
+        (result,) = response.json()["results"]
         query_metadata = result["target_data"]["application_metadata"]
         mod_4_to_expected_metadata_original = {
             1: not_base64_encoded_processable[:-1],
@@ -877,8 +940,8 @@ def add_and_wait_for_targets(
         )
         target_ids.add(target_id)
 
-    for target_id in target_ids:
-        vws_client.wait_for_target_processed(target_id=target_id)
+    for created_target_id in target_ids:
+        vws_client.wait_for_target_processed(target_id=created_target_id)
 
 
 @pytest.mark.usefixtures("verify_mock_vuforia")
@@ -1070,9 +1133,7 @@ class TestAcceptHeader:
         date = rfc_1123_date()
         request_path = "/v1/query"
         body = {"image": ("image.jpeg", image_content, "image/jpeg")}
-        content, content_type_header = encode_multipart_formdata(
-            fields=body,
-        )  # type: ignore[no-untyped-call]
+        content, content_type_header = encode_multipart_formdata(fields=body)
         method = POST
 
         access_key = vuforia_database.client_access_key
@@ -1118,9 +1179,7 @@ class TestAcceptHeader:
         date = rfc_1123_date()
         request_path = "/v1/query"
         body = {"image": ("image.jpeg", image_content, "image/jpeg")}
-        content, content_type_header = encode_multipart_formdata(
-            fields=body,
-        )  # type: ignore[no-untyped-call]
+        content, content_type_header = encode_multipart_formdata(fields=body)
         method = POST
 
         access_key = vuforia_database.client_access_key
@@ -1730,7 +1789,7 @@ class TestUpdate:
 
         body = {"image": ("image.jpeg", image_content, "image/jpeg")}
         response = query(vuforia_database=vuforia_database, body=body)
-        [result] = response.json()["results"]
+        (result,) = response.json()["results"]
         target_data = result["target_data"]
         target_timestamp = target_data["target_timestamp"]
         original_target_timestamp = int(target_timestamp)
@@ -1750,7 +1809,7 @@ class TestUpdate:
         response = query(vuforia_database=vuforia_database, body=body)
 
         assert_query_success(response=response)
-        [result] = response.json()["results"]
+        (result,) = response.json()["results"]
         assert result.keys() == {"target_id", "target_data"}
         assert result["target_id"] == target_id
         target_data = result["target_data"]
@@ -1879,7 +1938,7 @@ class TestDeleted:
                 total_waited += sleep_seconds
             else:
                 if response.json()["results"]:
-                    [result] = response.json()["results"]
+                    (result,) = response.json()["results"]
                     assert result["target_id"] == target_id
                     # We never see the target ID after having seen the server
                     # error.
@@ -2006,9 +2065,7 @@ class TestDateFormats:
         now = datetime.datetime.now(tz=gmt)
         date = now.strftime(datetime_format)
         request_path = "/v1/query"
-        content, content_type_header = encode_multipart_formdata(
-            fields=body,
-        )  # type: ignore[no-untyped-call]
+        content, content_type_header = encode_multipart_formdata(fields=body)
         method = POST
 
         access_key = vuforia_database.client_access_key
