@@ -14,8 +14,9 @@ import requests
 from freezegun import freeze_time
 from mock_vws import MockVWS
 from mock_vws.database import VuforiaDatabase
-from mock_vws.query_matchers import ExactMatcher
+from mock_vws.image_matchers import AverageHashMatcher, ExactMatcher
 from mock_vws.target import Target
+from mock_vws.target_raters import HardcodedTargetTrackingRater
 from PIL import Image
 from requests.exceptions import MissingSchema
 from requests_mock.exceptions import NoMockAddress
@@ -29,6 +30,13 @@ from tests.mock_vws.utils.usage_test_helpers import (
 )
 
 
+def _not_exact_matcher(
+    first_image_content: bytes,
+    second_image_content: bytes,
+) -> bool:
+    return first_image_content != second_image_content
+
+
 def request_unmocked_address() -> None:
     """
     Make a request, using `requests` to an unmocked, free local address.
@@ -106,11 +114,11 @@ class TestProcessingTime:
 
     # There is a race condition in this test type - if tests start to
     # fail, consider increasing the leeway.
-    LEEWAY = 0.1
+    LEEWAY = 0.5
 
     def test_default(self, image_file_failed_state: io.BytesIO) -> None:
         """
-        By default, targets in the mock take 0.5 seconds to be processed.
+        By default, targets in the mock takes 2 seconds to be processed.
         """
         database = VuforiaDatabase()
         with MockVWS() as mock:
@@ -120,23 +128,24 @@ class TestProcessingTime:
                 image=image_file_failed_state,
             )
 
-        expected = 0.5
-        assert abs(expected - time_taken) < self.LEEWAY
+        expected = 2
+        assert expected - self.LEEWAY < time_taken < expected + self.LEEWAY
 
     def test_custom(self, image_file_failed_state: io.BytesIO) -> None:
         """
         It is possible to set a custom processing time.
         """
         database = VuforiaDatabase()
-        with MockVWS(processing_time_seconds=0.1) as mock:
+        seconds = 5
+        with MockVWS(processing_time_seconds=seconds) as mock:
             mock.add_database(database=database)
             time_taken = processing_time_seconds(
                 vuforia_database=database,
                 image=image_file_failed_state,
             )
 
-        expected = 0.1
-        assert abs(expected - time_taken) < self.LEEWAY
+        expected = seconds
+        assert expected - self.LEEWAY < time_taken < expected + self.LEEWAY
 
 
 class TestDatabaseName:
@@ -220,21 +229,21 @@ class TestCustomBaseURLs:
         """
         An error if raised if a URL is given with no scheme.
         """
-        with pytest.raises(MissingSchema) as exc:
+        with pytest.raises(MissingSchema) as vws_exc:
             MockVWS(base_vws_url="vuforia.vws.example.com")
 
         expected = (
             'Invalid URL "vuforia.vws.example.com": No scheme supplied. '
             'Perhaps you meant "https://vuforia.vws.example.com".'
         )
-        assert str(exc.value) == expected
-        with pytest.raises(MissingSchema) as exc:
+        assert str(vws_exc.value) == expected
+        with pytest.raises(MissingSchema) as vwq_exc:
             MockVWS(base_vwq_url="vuforia.vwq.example.com")
         expected = (
             'Invalid URL "vuforia.vwq.example.com": No scheme supplied. '
             'Perhaps you meant "https://vuforia.vwq.example.com".'
         )
-        assert str(exc.value) == expected
+        assert str(vwq_exc.value) == expected
 
 
 class TestCustomQueryRecognizesDeletionSeconds:
@@ -243,61 +252,25 @@ class TestCustomQueryRecognizesDeletionSeconds:
     until it is not recognized by the query endpoint.
     """
 
-    LEEWAY = 0.15
+    LEEWAY = 0.5
 
     def test_default(
         self,
         high_quality_image: io.BytesIO,
     ) -> None:
         """
-        By default it takes zero seconds for the Query API on the mock to
+        By default it takes 2 seconds for the Query API on the mock to
         recognize that a target has been deleted.
 
         The real Query API takes between zero and two seconds.
         See ``test_query`` for more information.
         """
         database = VuforiaDatabase()
-        with MockVWS() as mock:
-            mock.add_database(database=database)
-            time_taken = recognize_deletion_seconds(
-                high_quality_image=high_quality_image,
-                vuforia_database=database,
-            )
-
-        expected = 0.2
-        assert abs(expected - time_taken) < self.LEEWAY
-
-    def test_with_no_processing_time(
-        self,
-        high_quality_image: io.BytesIO,
-    ) -> None:
-        """
-        We test this because it exercises some otherwise untouched code.
-        """
-        database = VuforiaDatabase()
-        with MockVWS(query_processes_deletion_seconds=0) as mock:
-            mock.add_database(database=database)
-            time_taken = recognize_deletion_seconds(
-                high_quality_image=high_quality_image,
-                vuforia_database=database,
-            )
-
-        expected = 0.2
-        assert abs(expected - time_taken) < self.LEEWAY
-
-    def test_custom(
-        self,
-        high_quality_image: io.BytesIO,
-    ) -> None:
-        """
-        It is possible to use set a custom amount of time that it takes for the
-        Query API on the mock to recognize that a target has been deleted.
-        """
-        # We choose a low time for a quick test.
-        query_recognizes_deletion = 0.5
-        database = VuforiaDatabase()
         with MockVWS(
-            query_recognizes_deletion_seconds=query_recognizes_deletion,
+            # Use the fastest available matcher.
+            query_match_checker=ExactMatcher(),
+            # Use the fastest available tracker.
+            target_tracking_rater=HardcodedTargetTrackingRater(rating=5),
         ) as mock:
             mock.add_database(database=database)
             time_taken = recognize_deletion_seconds(
@@ -305,8 +278,37 @@ class TestCustomQueryRecognizesDeletionSeconds:
                 vuforia_database=database,
             )
 
-        expected = query_recognizes_deletion
-        assert abs(expected - time_taken) < self.LEEWAY
+        expected = 2
+        assert expected - self.LEEWAY < time_taken < expected + self.LEEWAY
+
+    @pytest.mark.parametrize(
+        argnames=["seconds"],
+        # We include 0 because it exercises some otherwise untouched code.
+        argvalues=[(0,), (5,)],
+    )
+    def test_custom(
+        self,
+        high_quality_image: io.BytesIO,
+        seconds: int | float,
+    ) -> None:
+        """
+        It is possible to use set a custom amount of time that it takes for the
+        Query API on the mock to recognize that a target has been deleted.
+        """
+        database = VuforiaDatabase()
+        with MockVWS(
+            # Use the fastest available matcher.
+            query_match_checker=ExactMatcher(),
+            query_recognizes_deletion_seconds=seconds,
+        ) as mock:
+            mock.add_database(database=database)
+            time_taken = recognize_deletion_seconds(
+                high_quality_image=high_quality_image,
+                vuforia_database=database,
+            )
+
+        expected = seconds
+        assert expected - self.LEEWAY < time_taken < expected + self.LEEWAY
 
 
 class TestCustomQueryProcessDeletionSeconds:
@@ -317,7 +319,7 @@ class TestCustomQueryProcessDeletionSeconds:
 
     # There is a race condition in this test type - if tests start to
     # fail, consider increasing the leeway.
-    LEEWAY = 0.2
+    LEEWAY = 0.5
 
     def test_default(
         self,
@@ -331,7 +333,12 @@ class TestCustomQueryProcessDeletionSeconds:
         See ``test_query`` for more information.
         """
         database = VuforiaDatabase()
-        with MockVWS() as mock:
+        with MockVWS(
+            # Use the fastest available matcher.
+            query_match_checker=ExactMatcher(),
+            # Use the fastest available tracker.
+            target_tracking_rater=HardcodedTargetTrackingRater(rating=5),
+        ) as mock:
             mock.add_database(database=database)
             time_taken = process_deletion_seconds(
                 high_quality_image=high_quality_image,
@@ -339,7 +346,9 @@ class TestCustomQueryProcessDeletionSeconds:
             )
 
         expected = 3
-        assert abs(expected - time_taken) < self.LEEWAY
+        # We minus the leeway because we might start the timer after the
+        # deletion processing has started.
+        assert expected - self.LEEWAY < time_taken < expected + self.LEEWAY
 
     def test_custom(
         self,
@@ -350,10 +359,15 @@ class TestCustomQueryProcessDeletionSeconds:
         Query API on the mock to process that a target has been deleted.
         """
         # We choose a low time for a quick test.
-        query_processes_deletion = 0.1
+        # We choose a time high enough that the leeway won't be a problem.
+        query_processes_deletion = 5
         database = VuforiaDatabase()
         with MockVWS(
             query_processes_deletion_seconds=query_processes_deletion,
+            # Use the fastest available matcher.
+            query_match_checker=ExactMatcher(),
+            # Use the fastest available tracker.
+            target_tracking_rater=HardcodedTargetTrackingRater(rating=5),
         ) as mock:
             mock.add_database(database=database)
             time_taken = process_deletion_seconds(
@@ -362,7 +376,9 @@ class TestCustomQueryProcessDeletionSeconds:
             )
 
         expected = query_processes_deletion
-        assert abs(expected - time_taken) < self.LEEWAY
+        # We minus the leeway because we might start the timer after the
+        # deletion processing has started.
+        assert expected - self.LEEWAY < time_taken < expected + self.LEEWAY
 
 
 class TestTargets:
@@ -557,8 +573,8 @@ class TestAddDatabase:
                     mock.add_database(database=bad_database)
 
 
-class TestQueryMatchers:
-    """Tests for query matchers."""
+class TestQueryImageMatchers:
+    """Tests for query image matchers."""
 
     @staticmethod
     def test_exact_match(high_quality_image: io.BytesIO) -> None:
@@ -577,7 +593,7 @@ class TestQueryMatchers:
         re_exported_image = io.BytesIO()
         pil_image.save(re_exported_image, format="PNG")
 
-        with MockVWS(match_checker=ExactMatcher()) as mock:
+        with MockVWS(query_match_checker=ExactMatcher()) as mock:
             mock.add_database(database=database)
             target_id = vws_client.add_target(
                 name="example",
@@ -594,43 +610,7 @@ class TestQueryMatchers:
             different_image_result = cloud_reco_client.query(
                 image=re_exported_image,
             )
-            assert len(different_image_result) == 0
-
-    @staticmethod
-    def test_default(high_quality_image: io.BytesIO) -> None:
-        """The exact matcher is used by default."""
-        database = VuforiaDatabase()
-        vws_client = VWS(
-            server_access_key=database.server_access_key,
-            server_secret_key=database.server_secret_key,
-        )
-        cloud_reco_client = CloudRecoService(
-            client_access_key=database.client_access_key,
-            client_secret_key=database.client_secret_key,
-        )
-
-        pil_image = Image.open(fp=high_quality_image)
-        re_exported_image = io.BytesIO()
-        pil_image.save(re_exported_image, format="PNG")
-
-        with MockVWS() as mock:
-            mock.add_database(database=database)
-            target_id = vws_client.add_target(
-                name="example",
-                width=1,
-                image=high_quality_image,
-                application_metadata=None,
-                active_flag=True,
-            )
-            vws_client.wait_for_target_processed(target_id=target_id)
-            same_image_result = cloud_reco_client.query(
-                image=high_quality_image,
-            )
-            assert len(same_image_result) == 1
-            different_image_result = cloud_reco_client.query(
-                image=re_exported_image,
-            )
-            assert len(different_image_result) == 0
+            assert not different_image_result
 
     @staticmethod
     def test_custom_matcher(high_quality_image: io.BytesIO) -> None:
@@ -645,17 +625,11 @@ class TestQueryMatchers:
             client_secret_key=database.client_secret_key,
         )
 
-        def custom_matcher(
-            database_image_content: bytes,
-            query_image_content: bytes,
-        ) -> bool:
-            return database_image_content != query_image_content
-
         pil_image = Image.open(fp=high_quality_image)
         re_exported_image = io.BytesIO()
         pil_image.save(re_exported_image, format="PNG")
 
-        with MockVWS(match_checker=custom_matcher) as mock:
+        with MockVWS(query_match_checker=_not_exact_matcher) as mock:
             mock.add_database(database=database)
             target_id = vws_client.add_target(
                 name="example",
@@ -668,8 +642,182 @@ class TestQueryMatchers:
             same_image_result = cloud_reco_client.query(
                 image=high_quality_image,
             )
-            assert len(same_image_result) == 0
+            assert not same_image_result
             different_image_result = cloud_reco_client.query(
                 image=re_exported_image,
             )
             assert len(different_image_result) == 1
+
+    @staticmethod
+    def test_average_hash_matcher(
+        high_quality_image: io.BytesIO,
+        different_high_quality_image: io.BytesIO,
+    ) -> None:
+        """The average hash matcher matches similar images."""
+        database = VuforiaDatabase()
+        vws_client = VWS(
+            server_access_key=database.server_access_key,
+            server_secret_key=database.server_secret_key,
+        )
+        cloud_reco_client = CloudRecoService(
+            client_access_key=database.client_access_key,
+            client_secret_key=database.client_secret_key,
+        )
+
+        pil_image = Image.open(fp=high_quality_image)
+        re_exported_image = io.BytesIO()
+        pil_image.save(re_exported_image, format="PNG")
+
+        with MockVWS(
+            query_match_checker=AverageHashMatcher(threshold=10),
+        ) as mock:
+            mock.add_database(database=database)
+            target_id = vws_client.add_target(
+                name="example",
+                width=1,
+                image=high_quality_image,
+                application_metadata=None,
+                active_flag=True,
+            )
+            vws_client.wait_for_target_processed(target_id=target_id)
+            same_image_result = cloud_reco_client.query(
+                image=high_quality_image,
+            )
+            assert len(same_image_result) == 1
+            similar_image_result = cloud_reco_client.query(
+                image=re_exported_image,
+            )
+            assert len(similar_image_result) == 1
+
+            different_image_result = cloud_reco_client.query(
+                image=different_high_quality_image,
+            )
+            assert not different_image_result
+
+
+class TestDuplicatesImageMatchers:
+    """Tests for duplicates image matchers."""
+
+    @staticmethod
+    def test_exact_match(high_quality_image: io.BytesIO) -> None:
+        """The exact matcher matches only exactly the same images."""
+        database = VuforiaDatabase()
+        vws_client = VWS(
+            server_access_key=database.server_access_key,
+            server_secret_key=database.server_secret_key,
+        )
+
+        pil_image = Image.open(fp=high_quality_image)
+        re_exported_image = io.BytesIO()
+        pil_image.save(re_exported_image, format="PNG")
+
+        with MockVWS(duplicate_match_checker=ExactMatcher()) as mock:
+            mock.add_database(database=database)
+            target_id = vws_client.add_target(
+                name="example_0",
+                width=1,
+                image=high_quality_image,
+                application_metadata=None,
+                active_flag=True,
+            )
+            duplicate_target_id = vws_client.add_target(
+                name="example_1",
+                width=1,
+                image=high_quality_image,
+                application_metadata=None,
+                active_flag=True,
+            )
+            not_duplicate_target_id = vws_client.add_target(
+                name="example_2",
+                width=1,
+                image=re_exported_image,
+                application_metadata=None,
+                active_flag=True,
+            )
+            vws_client.wait_for_target_processed(target_id=target_id)
+            vws_client.wait_for_target_processed(target_id=duplicate_target_id)
+            vws_client.wait_for_target_processed(
+                target_id=not_duplicate_target_id,
+            )
+            duplicates = vws_client.get_duplicate_targets(target_id=target_id)
+            assert duplicates == [duplicate_target_id]
+
+    @staticmethod
+    def test_custom_matcher(high_quality_image: io.BytesIO) -> None:
+        """It is possible to use a custom matcher."""
+        database = VuforiaDatabase()
+        vws_client = VWS(
+            server_access_key=database.server_access_key,
+            server_secret_key=database.server_secret_key,
+        )
+
+        pil_image = Image.open(fp=high_quality_image)
+        re_exported_image = io.BytesIO()
+        pil_image.save(re_exported_image, format="PNG")
+
+        with MockVWS(duplicate_match_checker=_not_exact_matcher) as mock:
+            mock.add_database(database=database)
+            target_id = vws_client.add_target(
+                name="example_0",
+                width=1,
+                image=high_quality_image,
+                application_metadata=None,
+                active_flag=True,
+            )
+            duplicate_target_id = vws_client.add_target(
+                name="example_1",
+                width=1,
+                image=high_quality_image,
+                application_metadata=None,
+                active_flag=True,
+            )
+            not_duplicate_target_id = vws_client.add_target(
+                name="example_2",
+                width=1,
+                image=re_exported_image,
+                application_metadata=None,
+                active_flag=True,
+            )
+            vws_client.wait_for_target_processed(target_id=target_id)
+            vws_client.wait_for_target_processed(target_id=duplicate_target_id)
+            vws_client.wait_for_target_processed(
+                target_id=not_duplicate_target_id,
+            )
+            duplicates = vws_client.get_duplicate_targets(target_id=target_id)
+            assert duplicates == [not_duplicate_target_id]
+
+    @staticmethod
+    def test_average_hash_matcher(high_quality_image: io.BytesIO) -> None:
+        """The average hash matcher matches similar images."""
+        database = VuforiaDatabase()
+        vws_client = VWS(
+            server_access_key=database.server_access_key,
+            server_secret_key=database.server_secret_key,
+        )
+
+        pil_image = Image.open(fp=high_quality_image)
+        re_exported_image = io.BytesIO()
+        pil_image.save(re_exported_image, format="PNG")
+
+        with MockVWS(
+            duplicate_match_checker=AverageHashMatcher(threshold=10),
+        ) as mock:
+            mock.add_database(database=database)
+            target_id = vws_client.add_target(
+                name="example",
+                width=1,
+                image=high_quality_image,
+                application_metadata=None,
+                active_flag=True,
+            )
+            duplicate_target_id = vws_client.add_target(
+                name="example_1",
+                width=1,
+                image=re_exported_image,
+                application_metadata=None,
+                active_flag=True,
+            )
+            vws_client.wait_for_target_processed(target_id=target_id)
+            vws_client.wait_for_target_processed(target_id=duplicate_target_id)
+            duplicates = vws_client.get_duplicate_targets(target_id=target_id)
+            assert duplicates == [duplicate_target_id]
